package org.artifactory.security.access.emigrate;

import org.apache.commons.collections.CollectionUtils;
import org.artifactory.api.security.SecurityService;
import org.artifactory.security.access.AccessService;
import org.artifactory.security.access.emigrate.conveter.AccessSecurityEmigratorImpl;
import org.artifactory.security.access.emigrate.conveter.V5100ConvertResourceTypeToRepo;
import org.artifactory.security.access.emigrate.conveter.V600DecryptAllUsersCustomData;
import org.artifactory.security.access.emigrate.conveter.V6600CreateDefaultBuildAcl;
import org.artifactory.storage.db.security.service.access.emigrate.SecurityEmigratorFetchers;
import org.jfrog.common.StreamSupportUtils;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.Test;

import java.lang.reflect.Field;
import java.util.Arrays;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

/**
 * @author Omri Ziv
 */
public class AccessConvertersTest {

    @Mock
    private SecurityService securityService;
    @Mock
    private AccessService accessService;
    @Mock
    private SecurityEmigratorFetchers securityEmigratorFetchers;

    private AccessConverters accessConverters = null;

    @BeforeClass
    public void init() {
        MockitoAnnotations.initMocks(this);
        AccessSecurityEmigratorImpl accessSecurityEmigrator =
                new AccessSecurityEmigratorImpl(securityEmigratorFetchers);
        V5100ConvertResourceTypeToRepo resourceTypeConverter = new V5100ConvertResourceTypeToRepo(accessService);
        V600DecryptAllUsersCustomData decryptAllUsersCustomData = new V600DecryptAllUsersCustomData(securityService);
        V6600CreateDefaultBuildAcl createDefaultBuildAcl = new V6600CreateDefaultBuildAcl(accessService);


        accessConverters = new AccessConverters(accessSecurityEmigrator, resourceTypeConverter,
                decryptAllUsersCustomData, createDefaultBuildAcl);
    }

    @Test
    public void testFindDuplicatesInGetAll() {
        Set<Class<? extends AccessConverter>> set = StreamSupportUtils.stream(accessConverters.getAll())
                .map(AccessConverter::getClass)
                .collect(Collectors.toSet());
        assertEquals("AccessConverters.getAll contains duplication", set.size(),
                accessConverters.getAll().size());
    }


    @Test
    public void testGetAllContainsAll() {
        Field[] fields = AccessConverters.class.getDeclaredFields();
        List<Class<? extends AccessConverter>> accessConverterClassList =
                StreamSupportUtils.stream(accessConverters.getAll())
                        .map(AccessConverter::getClass)
                        .collect(Collectors.toList());

        List<Class<? extends AccessConverter>> fieldClasses = Arrays.stream(fields)
                .map(Field::getType)
                .filter(AccessConverter.class::isAssignableFrom)
                .map(clazz -> (Class<? extends AccessConverter>) clazz)
                .collect(Collectors.toList());

        List<Class<? extends AccessConverter>> notContains = StreamSupportUtils.stream(fieldClasses)
                .filter(clazz -> !accessConverterClassList.contains(clazz))
                .collect(Collectors.toList());

        assertTrue(String.format("Converters %s not contains in AccessConverters.getAll() function", notContains)
                , CollectionUtils.isEmpty(notContains));
    }

}
