package org.artifactory.storage.db.environment.converter.shared.version.v3.itest;

import lombok.AllArgsConstructor;
import lombok.Data;
import org.artifactory.common.home.ArtifactoryHome;
import org.artifactory.storage.db.environment.converter.shared.version.v3.NullEventCategoryToReplicationConverter;
import org.artifactory.storage.db.itest.DbBaseTest;
import org.jfrog.config.db.TemporaryDBChannel;
import org.jfrog.storage.util.DbUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.namedparam.SqlParameterSource;
import org.springframework.jdbc.core.namedparam.SqlParameterSourceUtils;
import org.springframework.jdbc.core.simple.SimpleJdbcInsert;
import org.testng.Assert;
import org.testng.annotations.AfterMethod;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

import java.sql.SQLException;
import java.util.List;

import static org.jfrog.storage.util.DbUtils.withConnection;
import static org.testng.Assert.assertFalse;

/**
 * @author Mor Merhav
 */
@Test
public class NullEventCategoryToReplicationConverterDbTest extends DbBaseTest {

    private static final String TABLE_NODE_EVENTS_ERRORS = "node_events_errors";

    private TemporaryDBChannel temporaryDBChannel;
    private JdbcTemplate jdbc;
    private SimpleJdbcInsert simpleJdbcInsert;

    @BeforeMethod
    public void beforeMethod() {
        temporaryDBChannel = new TemporaryDBChannel(ArtifactoryHome.get().getDBProperties());
        jdbc = temporaryDBChannel.asJdbcTemplate();
        simpleJdbcInsert = new SimpleJdbcInsert(jdbc.getDataSource());
    }

    @AfterMethod
    public void afterMethod() {
        jdbc.execute("TRUNCATE TABLE " + TABLE_NODE_EVENTS_ERRORS);
        temporaryDBChannel.close();
    }

    @Test
    public void testConvertNullEventCategoryToReplication() throws SQLException {
        NodeEventErrorsDBO eventErrorsDBO1 = new NodeEventErrorsDBO(1L, null);
        NodeEventErrorsDBO eventErrorsDBO2 = new NodeEventErrorsDBO(2L, null);
        NodeEventErrorsDBO eventErrorsDBO3 = new NodeEventErrorsDBO(3L, null);

        SqlParameterSource[] batch =
                SqlParameterSourceUtils.createBatch(eventErrorsDBO1, eventErrorsDBO2, eventErrorsDBO3);
        simpleJdbcInsert.withTableName(TABLE_NODE_EVENTS_ERRORS).executeBatch(batch);

        NullEventCategoryToReplicationConverter converter = new NullEventCategoryToReplicationConverter();
        converter.convert(ArtifactoryHome.get(), null, null);
        List<String> eventCategories =
                jdbc.queryForList("SELECT event_category FROM " + TABLE_NODE_EVENTS_ERRORS, String.class);

        Assert.assertNotNull(eventCategories);
        Assert.assertFalse(eventCategories.isEmpty());
        eventCategories.forEach(eventCategory -> Assert.assertEquals("REPLICATION", eventCategory));

        assertFalse(withConnection(jdbcHelper, conn -> DbUtils
                .isColumnNullable(conn.getMetaData(), dbProperties.getDbType(), TABLE_NODE_EVENTS_ERRORS,
                        "event_category")));
    }

    @Data
    @AllArgsConstructor
    static class NodeEventErrorsDBO {
        long errorId;
        String operationKey = "opKey";
        String eventCategory;
        long firstErrorTime = 1L;
        long lastErrorTime = 1L;
        short errorCount = 1;
        String errorMessage = "errMsg";
        long eventTime = 1L;
        short eventType = 1;
        String path = "path";

        public NodeEventErrorsDBO(long errorId, String eventCategory) {
            this.errorId = errorId;
            this.eventCategory = eventCategory;
        }
    }
}
