package org.artifactory.ui.rest.service.admin.advanced.storagesummary;

import org.artifactory.projects.ProjectsService;
import org.artifactory.rest.common.service.ArtifactoryRestRequest;
import org.artifactory.rest.common.service.RestResponse;
import org.artifactory.rest.common.service.RestService;
import org.artifactory.storage.StorageService;
import org.artifactory.storage.StorageSummaryInfo;
import org.artifactory.ui.rest.model.storage.ProjectStorageUsage;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;

/**
 * @author Inbar Tal
 */
@Component
@Scope(BeanDefinition.SCOPE_PROTOTYPE)
public class GetUIProjectsStorageUsage implements RestService {

    @Autowired
    private StorageService storageService;

    @Autowired
    private ProjectsService projectsService;

    @Override
    public void execute(ArtifactoryRestRequest request, RestResponse response) {
        StorageSummaryInfo info = storageService.getStorageSummaryInfoFromCache();
        List<String> userProjects = projectsService.getAllProjectsManagedByUser();
        List<ProjectStorageUsage> model = new ArrayList<>();
        userProjects.forEach(project -> {
            ProjectStorageUsage projectStorageUsage =
                    new ProjectStorageUsage(project, info.getProjectsTotalSizes().getOrDefault(project, 0L),
                            projectsService.getProjectStorageQuotaBytes(project));
            model.add(projectStorageUsage);
        });

        response.iModel(model);
    }
}
