package org.artifactory.ui.rest.service.admin.advanced.systemlogs;

import com.jfrog.sysconf.SysConfig;
import lombok.NonNull;
import lombok.extern.slf4j.Slf4j;
import org.artifactory.api.context.ContextHelper;
import org.artifactory.common.home.ArtifactoryHome;
import org.artifactory.rest.common.service.ArtifactoryRestRequest;
import org.artifactory.rest.common.service.RestResponse;
import org.artifactory.rest.common.service.RestService;
import org.artifactory.ui.rest.model.admin.advanced.systemlogs.SystemLiveLogsConfig;
import org.jfrog.common.util.SystemLogsUtil;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Component;

import java.io.File;
import java.util.Optional;

import static org.jfrog.common.util.SystemLogsUtil.DEFAULT_REFRESH_RATE_MILLISECONDS;

@Component
@Scope(BeanDefinition.SCOPE_PROTOTYPE)
@Slf4j
public class GetSysLiveLogsConfigService implements RestService {

    private final File logDir = ContextHelper.get().getArtifactoryHome().getLogDir();
    private static final String REFRESH_RATE_PROP_NAME = "shared.logging.view.refreshRate";

    @Override
    public void execute(@NonNull ArtifactoryRestRequest request, @NonNull RestResponse response) {
        SystemLiveLogsConfig systemLiveLogsConfig = new SystemLiveLogsConfig();
        systemLiveLogsConfig.setRefreshRateMillis(getRefreshRateFromSystemYaml());
        systemLiveLogsConfig.setLogs(SystemLogsUtil.getListOfLogs(logDir));
        response.iModel(systemLiveLogsConfig).buildResponse();
    }

    private long getRefreshRateFromSystemYaml() {
        SysConfig sysConfig = new SysConfig.Builder().withHome(
                ArtifactoryHome.get().getHomeDir().getAbsolutePath()).build();
        if (sysConfig == null) {
            return DEFAULT_REFRESH_RATE_MILLISECONDS;
        }
        Optional<String> value = sysConfig.get(REFRESH_RATE_PROP_NAME);
        if (value.isPresent()) {
            try {
                return SystemLogsUtil.getRefreshRateInMillis(value.get());
            } catch (Exception e) {
                log.warn("Failed to convert property " + REFRESH_RATE_PROP_NAME +
                        ". default value would be returned", e);
            }
        }
        return DEFAULT_REFRESH_RATE_MILLISECONDS;
    }
}
