package org.artifactory.ui.rest.model.artifacts.browse.treebrowser.nodes.actions;

import org.artifactory.addon.AddonsManager;
import org.artifactory.addon.xray.XrayAddon;
import org.artifactory.api.security.AuthorizationService;
import org.artifactory.projects.ProjectsService;
import org.artifactory.repo.RepoPath;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.testng.annotations.AfterMethod;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.times;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.verifyNoMoreInteractions;
import static org.mockito.Mockito.when;
import static org.testng.Assert.assertFalse;
import static org.testng.Assert.assertTrue;

/**
 * @author Yevdo Abramov
 * Created on 25/10/2020
 */
public class TreeNodeTabsPopulatorTest {

    @Mock
    private ProjectsService projectsService;
    @Mock
    private AddonsManager addonsManager;
    @Mock
    private XrayAddon xrayAddon;
    @Mock
    private AuthorizationService authorizationService;

    private TreeNodeTabsPopulator treeNodeTabsPopulator;

    @BeforeMethod
    public void setUp() {
        MockitoAnnotations.initMocks(this);
        treeNodeTabsPopulator = new TreeNodeTabsPopulator();
        treeNodeTabsPopulator.setProjectsService(projectsService);
        treeNodeTabsPopulator.setAddonsManager(addonsManager);
        treeNodeTabsPopulator.setAuthService(authorizationService);

        when(addonsManager.addonByType(XrayAddon.class)).thenReturn(xrayAddon);
    }

    @AfterMethod
    public void tearDown() {
        verifyNoMoreInteractions(projectsService, xrayAddon, authorizationService);
    }

    @Test
    public void testPopulateForRepositoryFromDefaultProject() {
        // given
        final String repoKey = "my_repo";
        TabsAndActions tabsAndActions = new TabsAndActions();
        tabsAndActions.setRepoPath(repoKey);
        tabsAndActions.setRepoType("local");
        when(projectsService.getProjectOfRepository(repoKey)).thenReturn(ProjectsService.DEFAULT_PROJECT);
        when(authorizationService.canManage(any(RepoPath.class))).thenReturn(true);
        when(xrayAddon.isXrayConfPerRepoAndIntegrationEnabled(repoKey)).thenReturn(false);

        // when
        treeNodeTabsPopulator.populateForRepository(tabsAndActions);

        // then
        assertTrue(tabsAndActions.getTabs().stream()
                .anyMatch(tab -> tab.getName().equals(TreeNodeTabsPopulator.EFFECTIVE_PERMISSION_TAB)));
        verify(projectsService).getProjectOfRepository(repoKey);
        verify(authorizationService, times(2)).canManage(any(RepoPath.class));
        verify(xrayAddon).isXrayConfPerRepoAndIntegrationEnabled(repoKey);
    }

    @Test
    public void testPopulateForRepositoryFromProjectUserProject() {
        // given
        final String repoKey = "my_repo";
        TabsAndActions tabsAndActions = new TabsAndActions();
        tabsAndActions.setRepoPath(repoKey);
        tabsAndActions.setRepoType("local");
        when(projectsService.getProjectOfRepository(repoKey)).thenReturn("user_project");
        when(authorizationService.canManage(any(RepoPath.class))).thenReturn(true);
        when(xrayAddon.isXrayConfPerRepoAndIntegrationEnabled(repoKey)).thenReturn(false);

        // when
        treeNodeTabsPopulator.populateForRepository(tabsAndActions);

        // then
        assertFalse(tabsAndActions.getTabs().stream()
                .anyMatch(tab -> tab.getName().equals(TreeNodeTabsPopulator.EFFECTIVE_PERMISSION_TAB)));
        verify(projectsService).getProjectOfRepository(repoKey);
        verify(authorizationService).canManage(any(RepoPath.class));
        verify(xrayAddon).isXrayConfPerRepoAndIntegrationEnabled(repoKey);
    }
}